# ringer
The Ringer Telique API provides access to telecommunications data, 
including caller name (CNAM) data, line type information, and more.

The API also includes services for checking phone numbers against 
Do Not Originate (DNO) and Do Not Call (DNC) databases, as well as 
STIR/SHAKEN call authentication validation.

## Authentication
This API uses IP whitelist authentication. Your server's IP address must be registered with
Ringer before making API calls. Contact support@ringer.tel to register your IP address.


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.18
- Package version: 1.0.0
- Generator version: 7.13.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://docs.ringer.tel/](https://docs.ringer.tel/)

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import ringer
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import ringer
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import ringer
from ringer.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.ringer.tel/v1
# See configuration.py for a list of all supported configuration parameters.
configuration = ringer.Configuration(
    host = "https://api.ringer.tel/v1"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: ipWhitelist
configuration.api_key['ipWhitelist'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['ipWhitelist'] = 'Bearer'


# Enter a context with an instance of the API client
with ringer.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = ringer.CICApi(api_client)
    crn = 8884835429 # int | Complex Routing Number (10-digit toll-free number)
    ani = 3037312000 # int | Valid Calling Party Number (10-digit)
    lata = 656 # int | Local Access and Transport Area (3-digit)

    try:
        # Get CIC information
        api_response = api_instance.get_cic_info(crn, ani, lata)
        print("The response of CICApi->get_cic_info:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling CICApi->get_cic_info: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.ringer.tel/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*CICApi* | [**get_cic_info**](docs/CICApi.md#get_cic_info) | **GET** /telique/cic/{crn}/{ani}/{lata} | Get CIC information
*CICApi* | [**get_cic_info_plain_text**](docs/CICApi.md#get_cic_info_plain_text) | **GET** /telique/cic/{crn}/{ani}/{lata}/plain | Get CIC information (plain text)
*CICApi* | [**get_cic_ror_info**](docs/CICApi.md#get_cic_ror_info) | **GET** /telique/cicror/{crn}/{ani}/{lata} | Get CIC information with ROR
*CICApi* | [**get_cic_ror_info_plain_text**](docs/CICApi.md#get_cic_ror_info_plain_text) | **GET** /telique/cicror/{crn}/{ani}/{lata}/plain | Get CIC information with ROR (plain text)
*CNAMApi* | [**get_cnam**](docs/CNAMApi.md#get_cnam) | **GET** /telique/cnam/{phoneNumber} | CNAM Lookup
*CNAMApi* | [**post_cnam**](docs/CNAMApi.md#post_cnam) | **POST** /telique/cnam | CNAM Lookup (POST)
*DNCApi* | [**get_dnc**](docs/DNCApi.md#get_dnc) | **GET** /telique/dnc/{num} | DNC Lookup
*DNCApi* | [**get_dnc_report**](docs/DNCApi.md#get_dnc_report) | **GET** /telique/dncreport | DNC Update Report
*DNCApi* | [**get_dnc_xml**](docs/DNCApi.md#get_dnc_xml) | **GET** /telique/dnc/{num}/xml | DNC Lookup (XML)
*DNOApi* | [**get_dno**](docs/DNOApi.md#get_dno) | **GET** /telique/dno/{num} | DNO Lookup
*DNOApi* | [**get_dno_xml**](docs/DNOApi.md#get_dno_xml) | **GET** /telique/dno/{num}/xml | DNO Lookup (XML)
*LocalRoutingNumberLRNApi* | [**get_lrn_info**](docs/LocalRoutingNumberLRNApi.md#get_lrn_info) | **GET** /telique/lrn/{phoneNumber} | Retrieve LRN for a phone number
*RORApi* | [**get_ror_info**](docs/RORApi.md#get_ror_info) | **GET** /telique/ror/{crn} | Get ROR information
*RORApi* | [**get_ror_info_plain_text**](docs/RORApi.md#get_ror_info_plain_text) | **GET** /telique/ror/{crn}/plain | Get ROR information (plain text)
*STIRSHAKENApi* | [**validate_stir_shaken**](docs/STIRSHAKENApi.md#validate_stir_shaken) | **POST** /telique/stirshaken/validate | Validate STIR/SHAKEN Identity


## Documentation For Models

 - [CICRORResponse](docs/CICRORResponse.md)
 - [CICResponse](docs/CICResponse.md)
 - [CNAMResponse](docs/CNAMResponse.md)
 - [DncUpdateReportInner](docs/DncUpdateReportInner.md)
 - [DnoResponse](docs/DnoResponse.md)
 - [Error](docs/Error.md)
 - [LrnResponse](docs/LrnResponse.md)
 - [RORResponse](docs/RORResponse.md)
 - [StirShakenRequest](docs/StirShakenRequest.md)
 - [StirShakenResponse](docs/StirShakenResponse.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="ipWhitelist"></a>
### ipWhitelist

- **Type**: API key
- **API key parameter name**: X-Forwarded-For
- **Location**: HTTP header


## Author

support@ringer.tel


